#!/usr/bin/env python3
import sqlite3
from datetime import datetime
import os

class Analytics:
    def __init__(self):
        self.db_path = os.path.join(os.path.dirname(__file__), 'analytics.db')
        self.init_db()
    
    def init_db(self):
        with sqlite3.connect(self.db_path) as conn:
            conn.execute('''
                CREATE TABLE IF NOT EXISTS visits (
                    id INTEGER PRIMARY KEY AUTOINCREMENT,
                    timestamp DATETIME NOT NULL,
                    search_terms TEXT
                )
            ''')
    
    def track_visit(self, search_terms=None):
        with sqlite3.connect(self.db_path) as conn:
            conn.execute('''
                INSERT INTO visits (timestamp, search_terms)
                VALUES (?, ?)
            ''', (datetime.utcnow(), search_terms))
    
    def get_stats(self):
        with sqlite3.connect(self.db_path) as conn:
            # Total visits
            total = conn.execute('SELECT COUNT(*) FROM visits').fetchone()[0]
            
            # Today's visits
            today = datetime.utcnow().date()
            today_count = conn.execute(
                'SELECT COUNT(*) FROM visits WHERE date(timestamp) = date(?)',
                (today,)
            ).fetchone()[0]
            
            # Total searches (non-null search terms)
            searches = conn.execute(
                'SELECT COUNT(*) FROM visits WHERE search_terms IS NOT NULL'
            ).fetchone()[0]
            
            return {
                'total_visits': total,
                'today_visits': today_count,
                'total_searches': searches
            }
