#!/usr/bin/env python3
import os
from datetime import datetime
import json

print("Content-Type: application/json")
print("Access-Control-Allow-Origin: *")
print()

try:
    log_file = "../analytics/visits.log"
    today = datetime.now().date()
    
    searches = []
    total_visits = 0
    today_visits = 0
    unique_terms = set()
    
    if os.path.exists(log_file):
        with open(log_file, 'r') as f:
            lines = [line.strip() for line in f if line.strip()]
            total_visits = len(lines)
            
            for line in lines:
                try:
                    timestamp_str, terms = line.split('|')
                    # Handle both timestamp formats
                    if ' ' in timestamp_str:  # Old format
                        timestamp = datetime.strptime(timestamp_str, '%Y-%m-%d %H:%M:%S.%f')
                    else:  # New format
                        timestamp = datetime.fromisoformat(timestamp_str)
                    
                    if timestamp.date() == today:
                        today_visits += 1
                    
                    if terms:
                        unique_terms.add(terms)
                    
                    # Format timestamp for display
                    formatted_time = timestamp.strftime('%Y-%m-%d %H:%M:%S')
                    searches.append(f"{formatted_time}|{terms}")
                except Exception as e:
                    continue
    
    print(json.dumps({
        'total_visits': total_visits,
        'today_visits': today_visits,
        'unique_terms': len(unique_terms),
        'recent_searches': searches[-20:]  # Last 20 searches
    }))

except Exception as e:
    print(json.dumps({
        'error': str(e),
        'total_visits': 0,
        'today_visits': 0,
        'unique_terms': 0,
        'recent_searches': []
    }))
