#!/usr/bin/env python3

from datetime import datetime
import json
import sys
import os
import requests
from http import server
import cgitb
cgitb.enable()  # For debugging

def main():
    # Enable CORS
    print("Content-Type: application/json")
    print("Access-Control-Allow-Origin: *")
    print("Access-Control-Allow-Methods: POST, OPTIONS")
    print("Access-Control-Allow-Headers: Content-Type")
    print()  # Empty line is required

    # Handle OPTIONS request for CORS preflight
    if os.environ.get('REQUEST_METHOD') == 'OPTIONS':
        return

    try:
        # Read the POST data
        content_length = int(os.environ.get('CONTENT_LENGTH', 0))
        post_data = sys.stdin.read(content_length)
        post = json.loads(post_data)
        with open("../analytics/visits.log", "a") as f: f.write(datetime.utcnow().isoformat() + "|" + str(post.get("content", "")) + "\n")

        # Create the parameters dictionary
        params = {
            'content': post['content'],
            'year_start': post['year_start'],
            'year_end': post['year_end'],
            'corpus': post['corpus'],
            'smoothing': post['smoothing'],
            'direct': True,           # Request direct data response
            'format': 'json'          # Request JSON format
        }

        # Add case_insensitive only if it's on
        if post.get('case_insensitive') == "on":
            params['case_insensitive'] = "true"

        # Handle special characters
        if '?' in params['content']:
            params['content'] = params['content'].replace('?', '*')
        if '@' in params['content']:
            params['content'] = params['content'].replace('@', '=>')

        # Make request to Google Ngrams
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/118.0.0.0 Safari/537.36'
        }
        response = requests.get(
            'https://books.google.com/ngrams/json',  # Use JSON endpoint
            params=params,
            headers=headers
        )
        
        if response.status_code == 200:
            try:
                data = response.json()
                print(json.dumps(data))
            except Exception as e:
                # Try regex fallback if JSON parsing fails
                import re
                res = re.findall(r'var data = (.*?);\n', response.text)
                if res:
                    print(res[0])
                else:
                    print(json.dumps({'error': 'No data found in response'}))
        else:
            print(json.dumps({'error': f'Request failed with status {response.status_code}'}))

    except Exception as e:
        print(json.dumps({'error': str(e)}))

if __name__ == "__main__":
    main()
